package org.netkernel.mod.cron.admin;

import org.netkernel.layer0.nkf.*;
import org.netkernel.layer0.representation.IHDSNode;
import org.netkernel.layer0.representation.impl.HDSBuilder;
import org.netkernel.mod.cron.services.CronUtils;
import org.netkernel.mod.cron.transport.CronTransport;
import org.netkernel.mod.cron.transport.NetKernelRequestJob;
import org.netkernel.module.standard.endpoint.StandardAccessorImpl;
import org.quartz.*;

public class CronPanelAccessor extends StandardAccessorImpl
{
	public void onSource(INKFRequestContext aContext) throws Exception
	{
		IHDSNode params=aContext.source("httpRequest:/params",IHDSNode.class);
		HDSBuilder b = new HDSBuilder();
		b.pushNode("param");
		b.importChildren(params);
		
		String action2=(String)params.getFirstValue("action2");
    	String status=null;
        if (action2!=null)
        {	String name=(String)params.getFirstValue("name");
			if (action2.equals("delete"))
			{   status=doDelete(name,aContext);
			}
			else if (action2.equals("run"))
			{   status=doRun(name,aContext);
			}
			else if (action2.equals("pause"))
			{   status=doPause(name,aContext);
			}
			else if (action2.equals("resume"))
			{   status=doResume(name,aContext);
			}
	    }
        b.addNode("status", status);
	    createIndexPage(b.getRoot(),aContext);
	}
	
	@SuppressWarnings("unchecked")
	private void createIndexPage(IHDSNode aParams, INKFRequestContext aContext ) throws Exception
	{	INKFRequest req=aContext.createRequest("active:xslt");
	    req.addArgument("operator","res:/org/netkernel/mod/cron/admin/styleJobs.xsl");
	    req.addArgument("operand","active:cronListAll");
	    req.addArgumentByValue("param",aParams);
	    req.setRepresentationClass(aContext.getThisRequest().getRepresentationClass());
	    INKFResponseReadOnly resp=aContext.issueRequestForResponse(req);
	
	    INKFResponse respOut=aContext.createResponseFrom(resp);
	    respOut.setExpiry(INKFResponse.EXPIRY_ALWAYS);
	    respOut.setHeader("WrappedControlPanel", Boolean.TRUE);
	}

	
	
	private String doDelete(String aName, INKFRequestContext aContext) throws Exception
	{	String status;
		Scheduler s=CronTransport.getSingleton().getScheduler();
	    boolean deleted = s.deleteJob(aName,Scheduler.DEFAULT_GROUP);
	    if (deleted)
	    {	status=aContext.formatMessage("MSG_MANUAL_DELETE", aName);
	    	aContext.logRaw(INKFLocale.LEVEL_INFO, status);
	    }
	    else
	    {   status=aContext.formatMessage("MSG_MANUAL_DELETE_FAIL", aName);
	    }
	    return status;
	}	
	
	private String doRun(String aName, INKFRequestContext aContext)
	{	String status;
		Scheduler s=CronTransport.getSingleton().getScheduler();
	    try
	    {	s.triggerJobWithVolatileTrigger(aName,Scheduler.DEFAULT_GROUP);
	    	status=aContext.formatMessage("MSG_MANUAL_EXEC", aName);
	    	aContext.logRaw(INKFLocale.LEVEL_INFO, status);
	    }
	    catch (SchedulerException e)
	    {   status=aContext.formatMessage("MSG_MANUAL_EXEC_FAIL", aName,e);
	    	aContext.logRaw(INKFLocale.LEVEL_WARNING, status);
	    }
	    return status;
	}

	private String doPause(String aName, INKFRequestContext aContext)
	{	String status;
		Scheduler s = CronTransport.getSingleton().getScheduler();
		try
		{	s.pauseJob(aName, Scheduler.DEFAULT_GROUP);
			JobDetail jd = CronUtils.getJob(aName,s);
			jd.getJobDataMap().put(NetKernelRequestJob.KEY_PAUSED, true);
			status=aContext.formatMessage("MSG_MANUAL_PAUSE", aName);
			aContext.logRaw(INKFLocale.LEVEL_INFO, status);
		}
		catch (SchedulerException e)
		{	status=aContext.formatMessage("MSG_MANUAL_PAUSE_FAIL", aName,e);
			aContext.logRaw(INKFLocale.LEVEL_WARNING, status);
		}
		return status;
	}
	
	private String doResume(String aName, INKFRequestContext aContext)
	{	String status;
		Scheduler s = CronTransport.getSingleton().getScheduler();
		try
		{	s.pauseJob(aName, Scheduler.DEFAULT_GROUP);
			JobDetail jd = CronUtils.getJob(aName,s);
			jd.getJobDataMap().put(NetKernelRequestJob.KEY_PAUSED, false);
			status=aContext.formatMessage("MSG_MANUAL_RESUME", aName);
			aContext.logRaw(INKFLocale.LEVEL_INFO, status);
		}
		catch (SchedulerException e)
		{	status=aContext.formatMessage("MSG_MANUAL_RESUME_FAIL", aName,e);
			aContext.logRaw(INKFLocale.LEVEL_WARNING, status);
		}
		return status;
	}

}
